# importing the required module
import matplotlib.pyplot as plt
import pandas as pd
# this example doesn't use Seaborn, due to some
# customization that's built-in to Matplotlib
#import seaborn as sns

# add ticker to change y-axis labels
import matplotlib.ticker as ticker

# our datasets:
metro_areas = ["New York–Newark–Jersey City, NY-NJ MSA",\
               "Los Angeles–Long Beach–Anaheim, CA MSA",\
               "Chicago–Naperville–Elgin, IL-IN MSA",\
               "Dallas–Fort Worth–Arlington, TX MSA",\
               "Houston–Pasadena–The Woodlands, TX MSA",\
               "Washington–Arlington–Alexandria, DC-VA-MD-WV MSA",\
               "Philadelphia–Camden–Wilmington, PA-NJ-DE-MD MSA",\
               "Atlanta–Sandy Springs–Roswell, GA MSA",\
               "Miami–Fort Lauderdale–West Palm Beach, FL MSA",\
               "Phoenix–Mesa–Chandler, AZ MSA"]
populations = [19557311, 12872322, 9274140, 7943685, 7368466,\
               6265183, 6241164, 6237435, 6139340, 5015678]

zipped = list(zip(metro_areas, populations))
df = pd.DataFrame(zipped, columns=['MSA', 'Population'])

# Create a custom formatter function
# this example is from https://saturncloud.io/blog/how-to-format-seabornmatplotlib-axis-tick-labels-from-number-to-thousands-or-millions/
def format_ticks(value, pos):
    if value >= 1e6:
        return f'{value*1e-6}M'
    elif value >= 1e3:
        return f'{value*1e-3}K'
    else:
        return f'{value}'
    
# Create a FuncFormatter object
formatter = ticker.FuncFormatter(format_ticks)

# make our graph
# https://www.geeksforgeeks.org/plotting-graph-using-seaborn-python/
# https://stackoverflow.com/questions/61330427/set-y-axis-in-millions

# specify colors:
# see https://matplotlib.org/stable/users/explain/colors/colors.html
# generally, be consistent with how you specify colors, but this shows a few different options:
bar_colors = ['tab:red', '#FF8000', 'yellow', 'tab:green', 'mediumseagreen',\
              'xkcd:sky blue', 'tab:blue', 'indigo', '#964B00', 'k']

fig, ax = plt.subplots()
ax.bar(metro_areas, populations, color=bar_colors)
plt.xticks(rotation=45, ha='right')

# Apply the formatter to the y-axis
ax.yaxis.set_major_formatter(formatter)

plt.show()

